aboutsummaryrefslogtreecommitdiffhomepage
path: root/hst/fs.go
diff options
context:
space:
mode:
Diffstat (limited to 'hst/fs.go')
-rw-r--r--hst/fs.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/hst/fs.go b/hst/fs.go
index 0dc95a99..b33d0492 100644
--- a/hst/fs.go
+++ b/hst/fs.go
@@ -13,11 +13,11 @@ import (
type FilesystemConfig interface {
// Valid returns whether the configuration is valid.
Valid() bool
- // Target returns the pathname of the mount point in the container.
- Target() *container.Absolute
- // Host returns a slice of all host paths used by this mount point.
+ // Path returns the target path in the container.
+ Path() *container.Absolute
+ // Host returns a slice of all host paths used by this operation.
Host() []*container.Absolute
- // Apply appends the [container.Op] implementing this mount point.
+ // Apply appends the [container.Op] implementing this operation.
Apply(ops *container.Ops)
fmt.Stringer